@@ -1,8 +1,8 @@
 from pywhat.distribution import Distribution
-from pywhat.helper import AvailableTags
+from pywhat.helper import AvailableTags, Keys
 from pywhat.identifier import Identifier
 
 pywhat_tags = AvailableTags().get_tags()
 
 
-__all__ = ["Identifier", "Distribution", "pywhat_tags"]
+__all__ = ["Identifier", "Distribution", "pywhat_tags", "Keys"]
